==> vue-form-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/form/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import Tooltip from "@dftvue2-opentiny/vue-tooltip";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyTooltip: Tooltip
  },
  provide: function provide() {
    return {
      TinyMode: "mobile-first"
    };
  },
  props: [].concat(props, ["validateOnRuleChange", "hideRequiredAsterisk", "model", "rules", "inlineMessage", "messageType", "statusIcon", "labelPosition", "showMessage", "size", "disabled", "labelWidth", "contentOffset", "labelSuffix", "inline", "responsiveLayout", "validateType", "validateIcon", "manual", "appendToBody", "popperOptions", "displayOnly"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("form", {
    staticClass: "w-full overflow-hidden p-4 sm:p-0",
    class: {
      "overflow-x-visible": _vm.labelPosition === "top" && !_vm.hideRequiredAsterisk,
      "grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4": _vm.inline
    },
    attrs: {
      "data-tag": "tiny-from"
    }
  }, [_vm._t("default"), _vm.displayOnly ? _c("tiny-tooltip", {
    ref: "tooltip",
    attrs: {
      "popper-class": "absolute",
      "manual": true,
      "effect": "light",
      "content": _vm.state.displayedValue,
      "placement": "top"
    },
    model: {
      value: _vm.state.tooltipVisible,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "tooltipVisible", $$v);
      },
      expression: "state.tooltipVisible"
    }
  }) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-form-2.23.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/form/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import Tooltip from '@opentinyvue/vue-tooltip';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyTooltip: Tooltip
  },
  provide: function provide() {
    return {
      TinyMode: "mobile-first"
    };
  },
  props: [].concat(props, ["validateOnRuleChange", "hideRequiredAsterisk", "model", "rules", "inlineMessage", "messageType", "statusIcon", "labelPosition", "showMessage", "size", "disabled", "labelWidth", "contentOffset", "labelSuffix", "inline", "responsiveLayout", "validateType", "validateIcon", "manual", "appendToBody", "popperOptions", "displayOnly", "showEmptyValue", "tooltipConfig"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("form", {
    staticClass: "w-full overflow-hidden",
    class: {
      "overflow-x-visible": _vm.labelPosition === "top" && !_vm.hideRequiredAsterisk,
      "grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 xl:grid-cols-4": _vm.inline
    },
    attrs: {
      "data-tag": "tiny-form"
    },
    on: {
      "submit": function submit($event) {
        $event.preventDefault();
      }
    }
  }, [_vm._t("default"), _vm.displayOnly ? _c("tiny-tooltip", {
    ref: "tooltip",
    attrs: {
      "popper-class": _vm.tooltipConfig.popperClass || "absolute",
      "manual": true,
      "effect": _vm.tooltipConfig.effect || "light",
      "content": _vm.state.displayedValue,
      "placement": _vm.tooltipConfig.placement || "top"
    },
    model: {
      value: _vm.state.tooltipVisible,
      callback: function callback($$v) {
        _vm.$set(_vm.state, "tooltipVisible", $$v);
      },
      expression: "state.tooltipVisible"
    }
  }) : _vm._e()], 2);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
